==> savane-3.6.tar.gz: savane-3.6/frontend/php/account/impersonate.php <==
<?php
# Become another user for testing his/her problems
# Copyright (C) 2007  Sylvain Beucler
#
# This file is part of Savane.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

require_once('../include/init.php');

if (!user_is_super_user())
  exit_error(_("You need to be site administrator to use this feature."));

extract(sane_import('post', array('user_name', 'uri')));

$new_uid = user_getid($user_name);
if ($new_uid == 0)
  exit_error(_("This user doesn't exist."));

# Modify session information to become the target user.
extract(sane_import('cookie', array('session_hash')));
$result = db_execute("UPDATE session SET user_id=? WHERE session_hash=?",
                     array($new_uid, $session_hash));
session_cookie('session_uid', $new_uid);

# Only allow redirections to the same website.
if (strlen ($uri) < 2
    || substr ($uri, 0, 1) !== '/' || substr ($uri, 1, 1) === '/')
  $uri = "/";

header("Location: $uri");
?>

==> savane-3.12.tar.gz: savane-3.12/frontend/php/account/impersonate.php <==
<?php
# Become another user for testing his/her problems
# Copyright (C) 1999, 2000 The SourceForge Crew
# Copyright (C) 2000-2006 Mathieu Roy
# Copyright (C) 2014, 2016, 2017 Assaf Gordon
# Copyright (C) 2001-2011, 2013, 2017 Sylvain Beucler
# Copyright (C) 2013, 2014, 2017-2023 Ineiev
#
# This file is part of Savane.
#
# Code written before 2008-03-30 (commit 8b757b2565ff) is distributed
# under the terms of the GNU General Public license version 3 or (at your
# option) any later version; further contributions are covered by
# the GNU Affero General Public license version 3 or (at your option)
# any later version.  The license notices for the AGPL and the GPL follow.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Savane is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# Savane is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

require_once('../include/init.php');

if (!user_is_super_user())
  exit_error(_("You need to be site administrator to use this feature."));

extract(sane_import('post', ['name' => 'user_name', 'internal_uri' => 'uri']));

$new_uid = user_getid($user_name);
if ($new_uid == 0)
  exit_error(_("This user doesn't exist."));

# Modify session information to become the target user.
extract(sane_import('cookie', ['hash' => 'session_hash']));
$result = db_execute("UPDATE session SET user_id=? WHERE session_hash=?",
                     array($new_uid, $session_hash));
session_cookie('session_uid', $new_uid);

header("Location: $uri");
?>
